"""fotoblog URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.conf import settings
from django.conf.urls.static import static
from django.urls import path, reverse_lazy
from django.contrib.auth.views import LoginView, LogoutView, PasswordChangeDoneView, PasswordChangeView
from authentication.views import SignupView, ProfilePictureView
from blog.views import home, restricted, PhotoUploadView, BlogPostCreateView

handler404 = 'blog.views.not_found'

urlpatterns = [
    path("admin/", admin.site.urls),
    path("", home, name='home'),
    path("restricted/", restricted, name='restricted'),
    path("login/",
         LoginView.as_view(
                template_name='authentication/login.html',
                redirect_authenticated_user=True),
         name='login'),
    path("logout/",
         LogoutView.as_view(template_name='authentication/logout.html'),
         name='logout'),
    path("UpdatePassword/",
         PasswordChangeView.as_view(template_name='authentication/update_password.html',
                                    success_url=reverse_lazy('update-password-done')),
         name='update-password'),
    path("UpdatePassword/done",
         PasswordChangeDoneView.as_view(template_name='authentication/update_password_done.html'),
         name='update-password-done'),
    path("signup",
         SignupView.as_view(),
         name='signup'),
    path("photo/upload",
         PhotoUploadView.as_view(),
         name='photo-upload'),
    path("user/profile_picture",
         ProfilePictureView.as_view(),
         name='account-photo-upload'),
    path("blog/create_post",
         BlogPostCreateView.as_view(),
         name='create-blog-post'),
]

if settings.DEBUG:
    urlpatterns += static(
        settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
